# myke

|               |                                           |
| ------------- | ----------------------------------------- |
| Repo          | https://codeberg.org/Fresh2dev/myke       |
| Repo Mirror   | https://www.Fresh2.dev/code/r/myke        |
| Documentation | https://www.Fresh2.dev/code/r/myke/i/docs |
| Funding       | https://www.Fresh2.dev/tip                |

---

```sh
PYTHONPATH=./src python -m myke --myke-file tests/resources/Mykefile -h

PYTHONPATH=./src ./tests/resources/Mykefile --myke-help
```


## Build

```sh
myke py-mkdocs
```

## Deploy

```sh
myke stack-up
```
